# this file is created by the cffi interface builder and contains the monetdb branch env variable.

monetdb_branch = 'Jul2021'
newer_then_jul2021 = False
